@@ -76,14 +76,19 @@ def heal(packagename: str, o: str) -> None:  # pragma: no cover
 
 
 @click.command()
-@click.argument("packagename")
-def deploy(packagename: str) -> None:
+def deploy() -> None:
     """
     Deployment routine
 
     :author: Julian M. Kleber
     """
-    pass  # pragma: no cover #TODO Implement
+    if os.path.isdir("dist") is True:
+        subprocess.run(["rm -r dist "], shell=True, check=True)
+    if os.path.isdir("build") is True:
+        subprocess.run(["rm -r build"], shell=True, check=True)
+    subprocess.run(["python3 -m build"], shell=True, check=True)
+    subprocess.run(["twine check dist/*"], shell=True, check=True)
+    subprocess.run(["python3 -m twine upload dist/*"], shell=True, check=True)
 
 
 spells.add_command(heal)
